document.addEventListener('DOMContentLoaded', function () {
    const keywordInput = document.getElementById('keywordInput');
    const addButton = document.getElementById('addButton');
    const importButton = document.getElementById('importButton');
    const exportButton = document.getElementById('exportButton');
    const searchInput = document.getElementById('searchButton');
    const searchButton = document.getElementById('searchButton');
    const keywordList = document.getElementById('keywordList');

    // 加载已存储的关键词并显示
    chrome.storage.local.get(['keywords'], function (result) {
        const keywords = result.keywords || [];
        keywords.forEach(displayKeyword);
    });

    // 添加关键词点击事件处理，已实现去重逻辑
    addButton.addEventListener('click', async function () {
        const keyword = keywordInput.value.trim();
        if (keyword) {
            let existingKeywords = [];
            try {
                const result = await chrome.storage.local.get(['keywords']);
                existingKeywords = result.keywords || [];
                if (!existingKeywords.includes(keyword)) {
                    addKeyword(keyword);
                    keywordInput.value = '';
                } else {
                    alert('该关键词已存在，请勿重复添加。');
                }
            } catch (error) {
                console.error('获取本地存储关键词列表出错:', error);
            }
        }
    });

    // 导入按钮点击事件处理，修复导入数据只保留一个的问题
    importButton.addEventListener('click', async function () {
        try {
            const [handle] = await window.showOpenFilePicker({
                types: [
                    {
                        description: 'JSON文件',
                        accept: {
                            'application/json': ['.json']
                        }
                    }
                ]
            });
            const file = await handle.getFile();
            const content = await file.text();
            const importedKeywords = JSON.parse(content);
            const existingKeywords = (await chrome.storage.local.get(['keywords']))['keywords'] || [];
            const allKeywords = [...existingKeywords,...importedKeywords]; // 合并已有和导入的关键词
            const uniqueKeywords = [...new Set(allKeywords)]; // 去重处理
            chrome.storage.local.set({ keywords: uniqueKeywords }, function () {
                uniqueKeywords.forEach(displayKeyword);
            });
        } catch (error) {
            alert('导入文件出错，请确保是有效的JSON文件。');
        }
    });

    // 导出按钮点击事件处理
    exportButton.addEventListener('click', function () {
        chrome.storage.local.get(['keywords'], function (result) {
            const keywords = result.keywords || [];
            const data = JSON.stringify(keywords);
            const blob = new Blob([data], { type: 'application/json' });
            const url = URL.createObjectURL(blob);
            const a = document.createElement('a');
            a.href = url;
            a.download = '关键词导出.json';
            a.click();
            URL.revokeObjectURL(url);
        });
    });

    function addKeyword(keyword) {
        chrome.storage.local.get(['keywords'], function (result) {
            const keywords = result.keywords || [];
            keywords.push(keyword);
            chrome.storage.local.set({ keywords: keywords });
            displayKeyword(keyword);
        });
    }

    function displayKeyword(keyword) {
        const li = document.createElement('li');
        li.textContent = keyword;
        const deleteButton = document.createElement('button');
        deleteButton.textContent = '删除';
        deleteButton.addEventListener('click', function () {
            removeKeyword(keyword);
        });
        li.appendChild(deleteButton);
        keywordList.appendChild(li);
    }

    function removeKeyword(keyword) {
        chrome.storage.local.get(['keywords'], function (result) {
            const keywords = result.keywords || [];
            const index = keywords.indexOf(keyword);
            if (index!== -1) {
                keywords.splice(index, 1);
                chrome.storage.local.set({ keywords: keywords });
                keywordList.innerHTML = '';
                keywords.forEach(displayKeyword);
            }
        });
    }
});